@@ -507,8 +507,7 @@ public class MQTTTest extends MQTTTestSupport {
 
    @Test(timeout = 60 * 1000)
    public void testSendAndReceiveRetainedLargeMessage() throws Exception {
-      AssertionLoggerHandler.startCapture();
-      try {
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
          byte[] payload = new byte[ActiveMQClient.DEFAULT_MIN_LARGE_MESSAGE_SIZE * 2];
          for (int i = 0; i < payload.length; i++) {
             payload[i] = '2';
@@ -554,9 +553,7 @@ public class MQTTTest extends MQTTTestSupport {
          subscriber3.disconnect();
          publisher.disconnect();
 
-         Assert.assertFalse(AssertionLoggerHandler.findText("Exception"));
-      } finally {
-         AssertionLoggerHandler.stopCapture();
+         Assert.assertFalse(loggerHandler.findText("Exception"));
       }
 
    }
@@ -2102,10 +2099,10 @@ public class MQTTTest extends MQTTTestSupport {
       final int port2 = 1885;
 
       final Configuration cfg1 = createDefaultConfig(1, false);
-      cfg1.addAcceptorConfiguration("mqtt1", "tcp://localhost:" + port1 + "?protocols=MQTT");
+      cfg1.setResolveProtocols(true).addAcceptorConfiguration("mqtt1", "tcp://localhost:" + port1 + "?protocols=MQTT");
 
       final Configuration cfg2 = createDefaultConfig(2, false);
-      cfg2.addAcceptorConfiguration("mqtt2", "tcp://localhost:" + port2 + "?protocols=MQTT");
+      cfg2.setResolveProtocols(true).addAcceptorConfiguration("mqtt2", "tcp://localhost:" + port2 + "?protocols=MQTT");
 
       final ActiveMQServer server1 = createServer(cfg1);
       server1.start();
